HasMutPtrTo

Type Alias HasMutPtrTo 

pub type HasMutPtrTo<T> = PhantomData<*mut T>;
Marks the containing type as having mutable pointers to T.

T is invariant, it also marks the containing type as not Send and not Sync.

See the crate root documentation for details on variance and marker traits.

Aliased Type

pub struct HasMutPtrTo<T>;